<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>Null</source>
        <comment>Type name</comment>
        <translation>Null</translation>
    </message>
    <message>
        <source>Bool</source>
        <comment>Type name</comment>
        <translation>Bool</translation>
    </message>
    <message>
        <source>Int</source>
        <comment>Type name</comment>
        <translation>Int</translation>
    </message>
    <message>
        <source>Real</source>
        <comment>Type name</comment>
        <translation>Real</translation>
    </message>
    <message>
        <source>String</source>
        <comment>Type name</comment>
        <translation>String</translation>
    </message>
    <message>
        <source>Name</source>
        <comment>Type name</comment>
        <translation>Name</translation>
    </message>
    <message>
        <source>Ref</source>
        <comment>Type name</comment>
        <translation>Ref</translation>
    </message>
    <message>
        <source>Array</source>
        <comment>Type name</comment>
        <translation>Array</translation>
    </message>
    <message>
        <source>Dict</source>
        <comment>Type name</comment>
        <translation>Dict</translation>
    </message>
    <message>
        <source>Stream</source>
        <comment>Type name</comment>
        <translation>Flujo</translation>
    </message>
    <message>
        <source>DebugCmd</source>
        <comment>Type name</comment>
        <translation>DebugCmd</translation>
    </message>
    <message>
        <source>DebugError</source>
        <comment>Type name</comment>
        <translation>DebugError</translation>
    </message>
    <message>
        <source>DebugEOF</source>
        <comment>Type name</comment>
        <translation>DebugEOF</translation>
    </message>
    <message>
        <source>DebugNone</source>
        <comment>Type name</comment>
        <translation>DebugNone</translation>
    </message>
    <message>
        <source>&lt;no name&gt;</source>
        <translation>&lt;sin nombre&gt;</translation>
    </message>
    <message>
        <source>Fatal Error</source>
        <translation>Error Fatal</translation>
    </message>
    <message>
        <source>Options: </source>
        <translation>Opciones: </translation>
    </message>
    <message>
        <source>Print help and exit</source>
        <translation>Imprimir ayuda y salir</translation>
    </message>
    <message>
        <source>Print version and exit</source>
        <translation>Imprimir versión y salir</translation>
    </message>
    <message>
        <source>Stop processing options</source>
        <translation>Parar procesamiento de opciones</translation>
    </message>
    <message>
        <source>Invalid commandline option : </source>
        <translation>Opción de comando inválida : </translation>
    </message>
    <message>
        <source>PDF files (*.pdf)</source>
        <translation>Archivos PDF (*.pdf)</translation>
    </message>
    <message>
        <source>Open file ...</source>
        <translation>Abrir archivo ...</translation>
    </message>
    <message>
        <source>Save file as ...</source>
        <translation>Guardar archivo como ...</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Si</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Aplicar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Dictionary</source>
        <translation>Diccionario</translation>
    </message>
    <message>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Página</translation>
    </message>
    <message>
        <source>&amp;Index</source>
        <translation>&amp;Indice</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Invalid %1 in config:
Name: %2
Data: %3
</source>
        <translation>Inválido %1 en configuración:
Nombre: %2
Datos: %3
</translation>
    </message>
    <message>
        <source>Expected: </source>
        <translation>Esperado: </translation>
    </message>
    <message>
        <source>Missing item in config</source>
        <translation>Componente perdido en la configuración</translation>
    </message>
    <message>
        <source>menu definition</source>
        <translation>definición de menú</translation>
    </message>
    <message>
        <source>menu item</source>
        <translation>componente de menú</translation>
    </message>
    <message>
        <source>2 or more parameters in item definition</source>
        <translation>2 o más parámetros en la definición de componente</translation>
    </message>
    <message>
        <source>toolbar item</source>
        <translation>componente de la barra de herramientas</translation>
    </message>
    <message>
        <source>4 parameters in item definition</source>
        <translation>4 parámetros en la definición de componente</translation>
    </message>
    <message>
        <source>toolbar definition</source>
        <translation>definición de la barra de herramientas</translation>
    </message>
    <message>
        <source>Cycle in menu detected</source>
        <translation>Ciclo en el menú detectado</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Catálogo</translation>
    </message>
    <message>
        <source>Menu items list</source>
        <translation>Lista de componentes del menú</translation>
    </message>
    <message>
        <source>&amp;Add object</source>
        <translation>&amp;Añadir objeto</translation>
    </message>
    <message>
        <source>Add and c&amp;lose</source>
        <translation>Añadir y &amp;cerrar</translation>
    </message>
    <message>
        <source>Stream</source>
        <translation>Flujo</translation>
    </message>
    <message>
        <source>Parameter missing for option : </source>
        <translation>Parámetro perdido para la opcion : </translation>
    </message>
    <message>
        <source>Set debug messages verbosity</source>
        <translation>Establecer verbosidad en mensajes de depuración</translation>
    </message>
    <message>
        <source>(n = -1 .. 5)</source>
        <translation>(n = -1 .. 5)</translation>
    </message>
    <message>
        <source>label item</source>
        <translation>etiqueta del componente</translation>
    </message>
    <message>
        <source>Content Stream</source>
        <translation>Contenido de flujo</translation>
    </message>
    <message>
        <source>Parameter</source>
        <translation>Parámetro</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operador</translation>
    </message>
    <message>
        <source>page</source>
        <comment>1</comment>
        <translation>página</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>2-4</comment>
        <translation>páginas</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>5+</comment>
        <translation>páginas</translation>
    </message>
    <message>
        <source>parameter</source>
        <comment>1</comment>
        <translation>parámetro</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>2-4</comment>
        <translation>parámetros</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>5+</comment>
        <translation>parámetros</translation>
    </message>
    <message>
        <source>child</source>
        <comment>1</comment>
        <translation>hijo</translation>
    </message>
    <message>
        <source>childs</source>
        <comment>2-4</comment>
        <translation>hijos</translation>
    </message>
    <message>
        <source>childs</source>
        <comment>5+</comment>
        <translation>hijos</translation>
    </message>
    <message>
        <source>Pick a file ...</source>
        <translation>Elige un archivo ...</translation>
    </message>
    <message>
        <source>New revision of document created</source>
        <translation>Nueva revisión del documento creada</translation>
    </message>
    <message>
        <source>Error occured while loading file</source>
        <translation>Error ocurrido mientras se cargaba el archivo</translation>
    </message>
    <message>
        <source>Image was not saved!</source>
        <translation>No se guardó la imagen!</translation>
    </message>
    <message>
        <source>Changed revision to:</source>
        <translation>Revisión cambiada a:</translation>
    </message>
    <message>
        <source>Saving as</source>
        <translation type="obsolete">Guardando como</translation>
    </message>
    <message>
        <source>Operators</source>
        <translation>Operadores</translation>
    </message>
    <message>
        <source>Warning: This document is linearized PDF!</source>
        <translation>Cuidado: Este documento es un PDF linearizado!</translation>
    </message>
    <message>
        <source>Show all operators</source>
        <translation>Mostrar todos los operadores</translation>
    </message>
    <message>
        <source>Show only text operators</source>
        <translation>Mostrar sólo operadores de texto</translation>
    </message>
    <message>
        <source>Showing all</source>
        <comment>mode</comment>
        <translation>Mostrando todo</translation>
    </message>
    <message>
        <source>Showing text. op.</source>
        <comment>mode</comment>
        <translation>Mostrando text. op.</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation>Acceso a un puntero nulo en </translation>
    </message>
    <message>
        <source>Show only font operators</source>
        <translation>Mostrar sólo los operadores de la fuente</translation>
    </message>
    <message>
        <source>Showing font. op.</source>
        <comment>mode</comment>
        <translation>Mostrando font. op.</translation>
    </message>
    <message>
        <source>Warning: This document is encrypted!</source>
        <translation>Cuidado: Este documento está cifrado!</translation>
    </message>
    <message>
        <source>Encryption filter:</source>
        <translation>Filtro de cifrado:</translation>
    </message>
    <message>
        <source>No page selected!</source>
        <translation>Ninguna página seleccionada!</translation>
    </message>
    <message>
        <source>Must define color</source>
        <translation>Debes definir un color</translation>
    </message>
    <message>
        <source>r,g,b must be number</source>
        <translation>r,g,b tienen que ser números</translation>
    </message>
    <message>
        <source>r,g,b must be from 0 to 255</source>
        <translation>r,g,b tienen que ser de 0 a 255</translation>
    </message>
    <message>
        <source>Left upper corner</source>
        <translation>Esquina superior izquierda</translation>
    </message>
    <message>
        <source>x position</source>
        <translation>posición x</translation>
    </message>
    <message>
        <source>y position</source>
        <translation>posición y</translation>
    </message>
    <message>
        <source>Right bottom corner</source>
        <translation>Esquina inferior derecha</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Set color</source>
        <translation>Establecer color</translation>
    </message>
    <message>
        <source>Set font properties</source>
        <translation>Establecer propiedades de fuente</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <translation>Establecer estilo de relleno de línea</translation>
    </message>
    <message>
        <source>Set line width</source>
        <translation>Establecer grosor de línea</translation>
    </message>
    <message>
        <source>Add system font</source>
        <translation>Añadir fuente del sistema</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <translation>Extraer texto desde página</translation>
    </message>
    <message>
        <source>Page rotated.</source>
        <translation>Página rotada.</translation>
    </message>
    <message>
        <source>MediaBox changed.</source>
        <translation>MediaBox cambiado.</translation>
    </message>
    <message>
        <source>No page or operator selected!</source>
        <translation>Página u operador no seleccionado!</translation>
    </message>
    <message>
        <source>Selected operator</source>
        <translation>Operador seleccionado</translation>
    </message>
    <message>
        <source>is not</source>
        <translation>no es</translation>
    </message>
    <message>
        <source>suitable for colour setting.</source>
        <translation>adecuado para ajuste de color.</translation>
    </message>
    <message>
        <source>suitable for line width change.</source>
        <translation>adecuado para cambio de grosor de línea.</translation>
    </message>
    <message>
        <source>Line width changed.</source>
        <translation>Grosor de la línea cambiado.</translation>
    </message>
    <message>
        <source>suitable for dash style change.</source>
        <translation>adecuado para cambio de estilo de relleno.</translation>
    </message>
    <message>
        <source>Dash pattern changed.</source>
        <translation>Patrón de relleno cambiado.</translation>
    </message>
    <message>
        <source>text operator</source>
        <translation>operador de texto</translation>
    </message>
    <message>
        <source>Font changed.</source>
        <translation>Fuente cambiada.</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Añadir fuente</translation>
    </message>
    <message>
        <source>Add system fonts</source>
        <translation>Añadir fuentes del sistema</translation>
    </message>
    <message>
        <source>Avaliable system fonts</source>
        <translation>Fuentes del sistema disponibles</translation>
    </message>
    <message>
        <source>Select system Type1 font</source>
        <translation>Seleccionar fuente Type1 del sistema</translation>
    </message>
    <message>
        <source>System font added.</source>
        <translation>Fuente del sistema añadida.</translation>
    </message>
    <message>
        <source>Text on page</source>
        <translation>Texto en página</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Text extracted from page</source>
        <translation>Texto extraido de página</translation>
    </message>
    <message>
        <source>Page text displayed</source>
        <translation>Texto de página visualizado</translation>
    </message>
    <message>
        <source>Operator must be</source>
        <translation>El operador tiene que ser</translation>
    </message>
    <message>
        <source>No preceding font operator found...</source>
        <translation>Ningún operador de fuente anterior encontrado...</translation>
    </message>
    <message>
        <source>Invalid operand type</source>
        <translation>Tipo de operando inválido</translation>
    </message>
    <message>
        <source>This option is not supported.</source>
        <translation>Esta opción no está soportada.</translation>
    </message>
    <message>
        <source>Show only graphical operators</source>
        <translation>Mostrar sólo operadores gráficos</translation>
    </message>
    <message>
        <source>Set relative position of a single operator</source>
        <translation>Establecer posición relativa de un operador simple</translation>
    </message>
    <message>
        <source>Set relative position</source>
        <translation>Establecer posición relativa</translation>
    </message>
    <message>
        <source>Set page tranformation matrix</source>
        <translation>Establecer matriz transformación de página</translation>
    </message>
    <message>
        <source>Change page rectangle</source>
        <translation>Cambiar rectángulo de página</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambiar</translation>
    </message>
    <message>
        <source>Page metrics</source>
        <translation>Métrica de página</translation>
    </message>
    <message>
        <source>Change effect</source>
        <translation>Cambiar efecto</translation>
    </message>
    <message>
        <source>Global change</source>
        <translation>Cambio global</translation>
    </message>
    <message>
        <source>Change line dash pattern</source>
        <translation>Cambiar patrón de relleno de línea</translation>
    </message>
    <message>
        <source>Line dashing patterns</source>
        <translation>Patrones de líneas de relleno</translation>
    </message>
    <message>
        <source>Solid line</source>
        <translation>Línea continua</translation>
    </message>
    <message>
        <source>Slightly dashed</source>
        <translation>Ligeramente punteada</translation>
    </message>
    <message>
        <source>Dot and dashed</source>
        <translation>Punto y guión</translation>
    </message>
    <message>
        <source>Not valid</source>
        <translation>No válido</translation>
    </message>
    <message>
        <source>Only text operators allowed!</source>
        <translation>Sólo operadores de texto permitidos!</translation>
    </message>
    <message>
        <source>Add page transformation matrix</source>
        <translation>Añadir matriz tranformación de página</translation>
    </message>
    <message>
        <source>Change page transformation matrix</source>
        <translation>Cambiar matriz transformación de página</translation>
    </message>
    <message>
        <source>Page transformation matrix description</source>
        <translation>Descripción de matriz tranformación de página</translation>
    </message>
    <message>
        <source>Page transformation description</source>
        <translation>Descripción de transformación de página</translation>
    </message>
    <message>
        <source>Select which transformations to use</source>
        <translation>Seleccionar transformaciones a usar</translation>
    </message>
    <message>
        <source>Translate (shift) page</source>
        <translation>Transladar (cambiar) página</translation>
    </message>
    <message>
        <source>Scale page</source>
        <translation>Escala de página</translation>
    </message>
    <message>
        <source>Skew page</source>
        <translation>Página torcida</translation>
    </message>
    <message>
        <source>Page translation</source>
        <translation>Translado de página</translation>
    </message>
    <message>
        <source>Page scaling</source>
        <translation>Escalamiento de página</translation>
    </message>
    <message>
        <source>Page skewing</source>
        <translation>Torciendo página</translation>
    </message>
    <message>
        <source>Invalid number supplied.</source>
        <translation>Número proporcionado inválido.</translation>
    </message>
    <message>
        <source>Page transformation matrix changed to </source>
        <translation>Matriz transformación de página cambiada a </translation>
    </message>
    <message>
        <source>Could not find text positioning.</source>
        <translation>No puedo encontrar el posicionamiento de texto.</translation>
    </message>
    <message>
        <source>Change relative text operator position</source>
        <translation>Cambiar posición relativa del operador de texto</translation>
    </message>
    <message>
        <source>Change relative text position</source>
        <translation>Cambiar posición relativa de texto</translation>
    </message>
    <message>
        <source>Operator position changed.</source>
        <translation>Posición del operador cambiada.</translation>
    </message>
    <message>
        <source>Showing graphic. op.</source>
        <comment>mode</comment>
        <translation>Mostrando op. graf.</translation>
    </message>
    <message>
        <source>element</source>
        <comment>1</comment>
        <translation>elemento</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>2-4</comment>
        <translation>elementos</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>5+</comment>
        <translation>elementos</translation>
    </message>
    <message>
        <source>item</source>
        <comment>1</comment>
        <translation>componente</translation>
    </message>
    <message>
        <source>items</source>
        <comment>2-4</comment>
        <translation>componentes</translation>
    </message>
    <message>
        <source>items</source>
        <comment>5+</comment>
        <translation>componentes</translation>
    </message>
    <message>
        <source>Add item to dictionary</source>
        <translation>Añadir componente a diccionario</translation>
    </message>
    <message>
        <source>Add element to array</source>
        <translation>Añadir elemento a array</translation>
    </message>
    <message>
        <source>Save page as image</source>
        <translation>Guardar página como imagen</translation>
    </message>
    <message>
        <source>Save selected area as image</source>
        <translation>Guardar área seleccionada como imagen</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Anotación</translation>
    </message>
    <message>
        <source>Draw line</source>
        <translation>Dibujar línea</translation>
    </message>
    <message>
        <source>Line was drawn.</source>
        <translation>La línea fue dibujada.</translation>
    </message>
    <message>
        <source>Encrypted content will show up as garbage and many operations will be impossible</source>
        <translation>El contenido cifrado se mostrará difuso y muchas operaciones serán imposibles</translation>
    </message>
    <message>
        <source>Rect was drawn.</source>
        <translation>La recta fue dibujada.</translation>
    </message>
    <message>
        <source>Draw rect</source>
        <translation>Dibujar recta</translation>
    </message>
    <message>
        <source>Add text</source>
        <translation>Añadir texto</translation>
    </message>
    <message>
        <source>position</source>
        <translation>posición</translation>
    </message>
    <message>
        <source>Set values</source>
        <translation>Establecer valores</translation>
    </message>
    <message>
        <source>Relative operator position (this is not absolute position)</source>
        <translation>Posición relativa del operador (esto no es una posición absoluta)</translation>
    </message>
    <message>
        <source>Relative operator position</source>
        <translation>Posición relativa del operador</translation>
    </message>
    <message>
        <source>Remove page</source>
        <translation>Eliminar página</translation>
    </message>
    <message>
        <source>View page</source>
        <translation>Ver página</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Usar:</translation>
    </message>
    <message>
        <source>input file</source>
        <translation>archivo de entrada</translation>
    </message>
    <message>
        <source>output file</source>
        <translation>archivo de salida</translation>
    </message>
    <message>
        <source>Input file must exist</source>
        <translation>El archivo de entrada debe existir</translation>
    </message>
    <message>
        <source>Output file must not exist</source>
        <translation>El archivo de salida no debe existir</translation>
    </message>
    <message>
        <source>is expecting two parameters</source>
        <translation>se esperan dos parámetros</translation>
    </message>
    <message>
        <source>Input file &apos;%1&apos; does not exist</source>
        <translation>El archivo de entrada &apos;%1&apos; no existe</translation>
    </message>
    <message>
        <source>Output file &apos;%1&apos; already exist</source>
        <translation>El archivo de salida &apos;%1&apos; ya existe</translation>
    </message>
    <message>
        <source>Delinearized</source>
        <translation>Delinearizado</translation>
    </message>
    <message>
        <source>Available functions:</source>
        <translation>Funciones disponibles:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Parámetros</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nombre del archivo</translation>
    </message>
    <message>
        <source>No function found matching &apos;%1&apos;</source>
        <translation>Ninguna función encontrada coincidente con &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many function found matching &apos;%1&apos;</source>
        <translation>Demasiadas funciones encontradas coincidentes con &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Matching functions</source>
        <translation>Funciones coincidentes</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Ejecutándose</translation>
    </message>
    <message>
        <source>First parameter is name of function to invoke (case insensitive) or its unambiguous part.</source>
        <translation>El primer parámetro es el nombre de la función a invocar (no sensible a may./min.) o su parte inequívoca.</translation>
    </message>
    <message>
        <source>Rest of parameters are passed to invoked function.</source>
        <translation>El resto de parámetros se pasan a la función invocada.</translation>
    </message>
    <message>
        <source>Run in commandline mode</source>
        <translation>Ejecutar en modo línea de comandos</translation>
    </message>
    <message>
        <source>file</source>
        <translation>archivo</translation>
    </message>
    <message>
        <source>Run script from script path or current directory if not found</source>
        <translation>Ejecutar script desde la ruta de scripts o desde el directorio actual si no se encuentra</translation>
    </message>
    <message>
        <source>Run script from current directory</source>
        <translation>Ejecutar script desde el directorio actual</translation>
    </message>
    <message>
        <source>code</source>
        <translation>código</translation>
    </message>
    <message>
        <source>Evaluate script code</source>
        <translation>Evaluar el código del script</translation>
    </message>
    <message>
        <source>function name</source>
        <translation>nombre de función</translation>
    </message>
    <message>
        <source>function parameter(s)</source>
        <translation>parametro(s) de función</translation>
    </message>
    <message>
        <source>option(s)</source>
        <translation>opción(es)</translation>
    </message>
    <message>
        <source>files(s)</source>
        <translation>archivo(s)</translation>
    </message>
    <message>
        <source>Please see the pdf specification for details.</source>
        <translation>Por favor mire la especificación de pdf para más detalles.</translation>
    </message>
    <message>
        <source>Text on a page.</source>
        <translation>Texto en una página.</translation>
    </message>
    <message>
        <source>Shortcut for</source>
        <translation>Atajo para</translation>
    </message>
    <message>
        <source>complex item is not shown</source>
        <comment>1</comment>
        <translation>componente complejo no mostrado</translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>2-4</comment>
        <translation>componentes complejos no mostrados</translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>5+</comment>
        <translation>componentes complejos no mostrados</translation>
    </message>
    <message>
        <source>out of range</source>
        <translation>fuera de rango</translation>
    </message>
    <message>
        <source>Search text</source>
        <translation>Buscar en texto</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Encontrar</translation>
    </message>
    <message>
        <source>Text :</source>
        <translation>Texto :</translation>
    </message>
    <message>
        <source>Find what</source>
        <translation>Encontran qué</translation>
    </message>
    <message>
        <source>On currently viewed page only</source>
        <translation>En la página visitada actualmente sólo</translation>
    </message>
    <message>
        <source>Nothing was found.</source>
        <translation>No se encontró nada.</translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation>Sobreescribir?</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>&amp;Arriba</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>&amp;Abajo</translation>
    </message>
    <message>
        <source>File called &quot;%1&quot; already exists. Do you want to overwrite it?</source>
        <translation>El archivo llamado &quot;%1&quot; ya existe. Quieres sobreescribirlo?</translation>
    </message>
    <message>
        <source>Delinearization failed!</source>
        <translation>La delinearización falló!</translation>
    </message>
    <message>
        <source>Colour changed</source>
        <translation>Color cambiado</translation>
    </message>
    <message>
        <source>for</source>
        <translation>para</translation>
    </message>
    <message>
        <source>operators</source>
        <translation>operadores</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Anotaciones</translation>
    </message>
    <message>
        <source>Input and output files must be different</source>
        <translation>Los archivos de entrada y salida tienen que ser diferentes</translation>
    </message>
    <message>
        <source>changeable</source>
        <translation>variable</translation>
    </message>
    <message>
        <source>Delinearize</source>
        <translation>Delinearizar</translation>
    </message>
    <message>
        <source>%1 added to page</source>
        <translation>%1 añadido a la página</translation>
    </message>
    <message>
        <source>Operator %1 is not changeable</source>
        <translation>El operador %1 no es variable</translation>
    </message>
    <message>
        <source>Operator cm must have array with 6 numbers as parameter!</source>
        <translation>El operador cm tiene que tener un array con 6 números como parámetros!</translation>
    </message>
    <message>
        <source>X and Y position must be a number</source>
        <translation>Las posiciones X e Y tienen que ser números</translation>
    </message>
    <message>
        <source>Dictionary has no type!</source>
        <translation>El diccionario no tiene caracteres!</translation>
    </message>
    <message>
        <source>Maybe bad stream!</source>
        <translation>Quizás mal flujo!</translation>
    </message>
    <message>
        <source>%1 is requirement for %2, but not found for it !</source>
        <translation>%1 es requerimiento para %2, pero lo encuentra !</translation>
    </message>
    <message>
        <source>For child %1 of %2 is requirement %3 subchild, but has %4</source>
        <translation>Para hijo %1 de %2 es requerimiento subhijo %3, pero tiene %4</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have 1 parameter, but has %2 !</source>
        <translation>El operador &apos;%1&apos; debería tener 1 parámetro, pero tiene %2 !</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have %2 parameters, but has %3 !</source>
        <translation>El operador &apos;%1&apos; debería tener %2 parámetros, pero tiene %3 !</translation>
    </message>
    <message>
        <source>Page parameter must be defined!</source>
        <translation>El parámetro de página tendría que definirse!</translation>
    </message>
    <message>
        <source>Matrix is in bad state !</source>
        <translation>Matriz en mal estado !</translation>
    </message>
    <message>
        <source>Document is read-only</source>
        <translation>El documento es de sólo-lectura</translation>
    </message>
    <message>
        <source>Move one level up</source>
        <translation>Mover un nivel hacia arriba</translation>
    </message>
    <message>
        <source>Move one level down</source>
        <translation>Mover un nivel hacia abajo</translation>
    </message>
    <message>
        <source>Invalid operation</source>
        <translation>Operación inválida</translation>
    </message>
    <message>
        <source>xml files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as text file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font size (in points)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line width (in points)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply from page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many pages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>annotation_type</name>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Enlace</translation>
    </message>
    <message>
        <source>FreeText</source>
        <translation>TextoLibre</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Cuadrado</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Círculo</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Polígono</translation>
    </message>
    <message>
        <source>PolyLine</source>
        <translation>PoliLínea</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Resaltar</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Subrayar</translation>
    </message>
    <message>
        <source>Squiggly</source>
        <translation>Squiggly</translation>
    </message>
    <message>
        <source>StrikeOut</source>
        <translation>Tachar</translation>
    </message>
    <message>
        <source>Stamp</source>
        <translation>Sellar</translation>
    </message>
    <message>
        <source>Caret</source>
        <translation>Caret</translation>
    </message>
    <message>
        <source>Ink</source>
        <translation>Tinta</translation>
    </message>
    <message>
        <source>Popup</source>
        <translation>Popup</translation>
    </message>
    <message>
        <source>Fileattachement</source>
        <translation>ArchivoAdjunto</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Película</translation>
    </message>
    <message>
        <source>Widget</source>
        <translation>Trasto</translation>
    </message>
    <message>
        <source>Screen</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <source>Printermark</source>
        <translation>MarcaDeImpresión</translation>
    </message>
    <message>
        <source>Trapnet</source>
        <translation>Trapnet</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>MarcaDeAgua</translation>
    </message>
    <message>
        <source>3D</source>
        <translation>3D</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
</context>
<context>
    <name>gui::AboutWindow</name>
    <message>
        <source>PDF editor for unix systems</source>
        <translation type="obsolete">PDF editor pro para sistemas unix</translation>
    </message>
    <message>
        <source>Project leader</source>
        <translation type="obsolete">Líder del proyecto</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="obsolete">Autores</translation>
    </message>
    <message>
        <source>About program</source>
        <translation>Sobre el programa</translation>
    </message>
    <message>
        <source>Compiled</source>
        <translation>Compilado</translation>
    </message>
    <message>
        <source>This program is distributed under terms of GNU GPL</source>
        <translation>Este programa se distribuye bajo los términos de GNU GPL</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Free program for PDF document manipulation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, QSA %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::AddItemDialog</name>
    <message>
        <source>Add object</source>
        <translation>Añadir objeto</translation>
    </message>
    <message>
        <source>Type and value of new object</source>
        <translation>Tipo y valor del nuevo objeto</translation>
    </message>
    <message>
        <source>New empty Dictionary</source>
        <translation>Nuevo Diccionario vacío</translation>
    </message>
    <message>
        <source>New empty Array</source>
        <translation>Nuevo Array vacío</translation>
    </message>
    <message>
        <source>Property name</source>
        <translation>Nombre de la propiedad</translation>
    </message>
    <message>
        <source>No object type selected</source>
        <translation>Ningún tipo de objeto seleccionado</translation>
    </message>
    <message>
        <source>Entered property is not valid</source>
        <translation>La propiedad entrada no es válida</translation>
    </message>
    <message>
        <source>Name of new property must be specified</source>
        <translation>El nombre de la nueva propiedad tiene que ser especificado</translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; added to dictionary</source>
        <translation>Propiedad &apos;%1&apos; añadida a diccionario</translation>
    </message>
    <message>
        <source>Property added to end of array</source>
        <translation>Propiedad añadida al final de array</translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; already exist as %2</source>
        <translation>Propiedad &apos;%1&apos; ya existe como %2</translation>
    </message>
    <message>
        <source>Reference target does not exist!</source>
        <translation>La referencia destino no existe!</translation>
    </message>
    <message>
        <source>Add to position</source>
        <translation>Añadido a posición</translation>
    </message>
    <message>
        <source>Append to end</source>
        <translation>Agregado al final</translation>
    </message>
    <message>
        <source>Property added to position %1 in array</source>
        <translation>Propiedad añadida a posición %1 en array</translation>
    </message>
    <message>
        <source>Array index %1 out of range</source>
        <translation>Indice %1 del array fuera de rango</translation>
    </message>
</context>
<context>
    <name>gui::AnnotDialog</name>
    <message>
        <source>Text Annotation</source>
        <translation>Anotación de Texto</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contenido</translation>
    </message>
    <message>
        <source>Icon &amp;Name</source>
        <translation>Nombre del &amp;Icono</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insertar</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>NewParagraph</source>
        <translation>Nuevo Párrafo</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Paragraph</source>
        <translation>Párrafo</translation>
    </message>
    <message>
        <source>&amp;State</source>
        <translation>&amp;Estado</translation>
    </message>
    <message>
        <source>Marked</source>
        <translation>Marcado</translation>
    </message>
    <message>
        <source>Unmarked</source>
        <translation>Desmarcado</translation>
    </message>
    <message>
        <source>State &amp;Model</source>
        <translation>State &amp;Model</translation>
    </message>
    <message>
        <source>Review</source>
        <translation>Revisión</translation>
    </message>
    <message>
        <source>&amp;Text Annotation</source>
        <translation>Anotación de &amp;Texto</translation>
    </message>
    <message>
        <source>&amp;Destination</source>
        <translation>&amp;Destino</translation>
    </message>
    <message>
        <source>&amp;Highlight mode</source>
        <translation>Modo &amp;resaltado</translation>
    </message>
    <message>
        <source>N - None</source>
        <translation>N - Ninguno</translation>
    </message>
    <message>
        <source>I - Invert</source>
        <translation>I - Invertir</translation>
    </message>
    <message>
        <source>O - Outline</source>
        <translation>O - Contorno</translation>
    </message>
    <message>
        <source>P - Push</source>
        <translation>P - Poner</translation>
    </message>
    <message>
        <source>&amp;Link Annotation</source>
        <translation>A&amp;notación de Enlace</translation>
    </message>
    <message>
        <source>Add new annotation</source>
        <translation>Añadir nueva anotación</translation>
    </message>
</context>
<context>
    <name>gui::Base</name>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>No init script found - check your configuration</source>
        <translation>Ningún script de inicio encontrado - comprueba tu configuración</translation>
    </message>
    <message>
        <source>Looked for</source>
        <comment>scripts</comment>
        <translation>Buscado</translation>
    </message>
    <message>
        <source>Error running</source>
        <translation>Error de ejecución</translation>
    </message>
    <message>
        <source>Script not found</source>
        <translation>Script no encontrado</translation>
    </message>
</context>
<context>
    <name>gui::BaseCore</name>
    <message>
        <source>Error in callback handler: </source>
        <translation>Error en manejador de llamadas: </translation>
    </message>
    <message>
        <source>Exception in callback handler: </source>
        <translation>Excepción en manejador de llamadas: </translation>
    </message>
    <message>
        <source>Unknown exception in script occured</source>
        <translation>Excepción desconocida ocurrida en script</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation>Acceso a puntero nulo en </translation>
    </message>
    <message>
        <source>Invalid object given for parameter %1 in </source>
        <translation>Objeto inválido dado por parámetro %1 en </translation>
    </message>
    <message>
        <source>Expected</source>
        <comment>object type</comment>
        <translation>Expected</translation>
    </message>
    <message>
        <source>Got</source>
        <comment>object type</comment>
        <translation>Got</translation>
    </message>
    <message>
        <source>In script</source>
        <translation>En script</translation>
    </message>
    <message>
        <source>line</source>
        <translation>línea</translation>
    </message>
    <message>
        <source>Exception in </source>
        <translation>Excepción en </translation>
    </message>
</context>
<context>
    <name>gui::BaseGUI</name>
    <message>
        <source>No document opened</source>
        <translation>Ningún documento abierto</translation>
    </message>
</context>
<context>
    <name>gui::ColorTool</name>
    <message>
        <source>Choose color</source>
        <translation>Elegir color</translation>
    </message>
    <message>
        <source>Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::HelpWindow</name>
    <message>
        <source>help</source>
        <translation>ayuda</translation>
    </message>
</context>
<context>
    <name>gui::MergeDialog</name>
    <message>
        <source>Insert pages from another document</source>
        <translation>Insertar páginas desde otro documento</translation>
    </message>
    <message>
        <source>&amp;Filename</source>
        <translation>&amp;Nombre del archivo</translation>
    </message>
    <message>
        <source>Open file with pages to be inserted</source>
        <translation>Abrir archivo con las páginas a insertarse</translation>
    </message>
</context>
<context>
    <name>gui::MultiTreeWindow</name>
    <message>
        <source>Tree</source>
        <translation>Arbol</translation>
    </message>
    <message>
        <source>Close current tab</source>
        <translation>Cerrar pestaña actual</translation>
    </message>
    <message>
        <source>Document tree</source>
        <translation>Arbol del documento</translation>
    </message>
    <message>
        <source>Switch to ...</source>
        <translation>Intercambiar a ...</translation>
    </message>
</context>
<context>
    <name>gui::OptionWindow</name>
    <message>
        <source>options</source>
        <translation>opciones</translation>
    </message>
    <message>
        <source>Icon Path</source>
        <translation>Ruta de Iconos</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>Advanced mode</source>
        <translation>Modo avanzado</translation>
    </message>
    <message>
        <source>Object tree</source>
        <translation>Arbol objeto</translation>
    </message>
    <message>
        <source>Document dictionary</source>
        <translation>Diccionario documento</translation>
    </message>
    <message>
        <source>Object dictionaries</source>
        <translation>Diccionarios objeto</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Contornos</translation>
    </message>
    <message>
        <source>Graphic objects</source>
        <translation>Objetos gráficos</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Anotaciones</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <source>Simple Objects</source>
        <translation>Objetos Simples</translation>
    </message>
    <message>
        <source>Show return value of executed scripts in console</source>
        <translation>Mostrar valor de retorno de los scripts ejecutados en consola</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Barras de herramientas</translation>
    </message>
    <message>
        <source>History file</source>
        <translation>Archivo de histórico</translation>
    </message>
    <message>
        <source>Max. lines in history</source>
        <translation>Max. líneas en histórico</translation>
    </message>
    <message>
        <source>Look and Feel</source>
        <translation>Mirar y Sentir</translation>
    </message>
    <message>
        <source>You can specify overall visual style</source>
        <translation>Puedes especificar el estilo visual global</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Remember path of last opened/saved file</source>
        <translation>Recordar la ruta del último archivo abierto/guardado</translation>
    </message>
    <message>
        <source>Turning on advanced mode will allow more powerful (but also more dangerous) changes to edited document.</source>
        <translation>Activar el modo avanzado permitirá más cambios poderosos (pero también más peligrosos) al documento editado.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Advanced mode will affect only newly opened files</source>
        <translation>&lt;b&gt;Nota&lt;/b&gt;: el cambio al Modo Avanzado afectará sólo a los archivos abiertos recientemente</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <source>You can use environment variables (for example $HOME) in settings on this page</source>
        <translation>Puedes usar las variables de entorno (por ejemplo $HOME) en ajustes en esta página</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Icon Path will take effect on next program start</source>
        <translation>&lt;b&gt;Nota&lt;/b&gt;: el cambio de la Ruta de Iconos afectará en el próximo inicio del programa</translation>
    </message>
    <message>
        <source>Console log file</source>
        <translation>Archivo log de consola</translation>
    </message>
    <message>
        <source>These objects will be shown in the object tree</source>
        <translation>Estos objetos serán mostrados en el árbol objeto</translation>
    </message>
    <message>
        <source>These toolbars will be shown:</source>
        <translation>Estas barras de herramientas serán mostradas:</translation>
    </message>
    <message>
        <source>Show errors from event handlers</source>
        <translation>Mostrar errores desde los manejadores de evento</translation>
    </message>
    <message>
        <source>Content Streams</source>
        <translation>Contenido de Flujos</translation>
    </message>
    <message>
        <source>Show command editor</source>
        <translation>Mostrar editor de comandos</translation>
    </message>
    <message>
        <source>Show command line</source>
        <translation>Mostrar línea de comandos</translation>
    </message>
    <message>
        <source>Editable command line</source>
        <translation>Línea de comandos editable</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Ruta de Scripts</translation>
    </message>
    <message>
        <source>Scripts to run on start</source>
        <translation>Scripts a ejecutar al inicio</translation>
    </message>
    <message>
        <source>You can set fonts used in application</source>
        <translation>Puedes establecer fuentes utilizadas en la aplicación</translation>
    </message>
    <message>
        <source>Application font</source>
        <translation>Fuente de aplicación</translation>
    </message>
    <message>
        <source>Console font</source>
        <translation>Fuente de consola</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Icon theme</translation>
    </message>
    <message>
        <source>Use big icons</source>
        <translation>Usar iconos grandes</translation>
    </message>
    <message>
        <source>Show hidden properties</source>
        <translation>Mostrar propiedades ocultas</translation>
    </message>
    <message>
        <source>Allow editing read-only properties</source>
        <translation>Permitir editar propiedades de sólo-lectura</translation>
    </message>
    <message>
        <source>Commandline</source>
        <translation>Línea de comandos</translation>
    </message>
    <message>
        <source>Commandline options</source>
        <translation>Opciones de línea de comandos</translation>
    </message>
    <message>
        <source>Options affecting object tree and property editor</source>
        <translation>Opciones que afectan al árbol de objetos y al editor de propiedades</translation>
    </message>
    <message>
        <source>Sort dictionary items alphabetically</source>
        <translation>Ordenar diccionario alfabéticamente</translation>
    </message>
    <message>
        <source>History options</source>
        <translation>Opciones de histórico</translation>
    </message>
    <message>
        <source>Statusbar font</source>
        <translation>Fuente de la barra de estado</translation>
    </message>
    <message>
        <source>Show return value also for complex types
(possibly long output)</source>
        <translation>Mostrar valor de retorno también para tipos complejo
(posiblemente salida larga)</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing icon theme will take effect on next program start</source>
        <translation>&lt;b&gt;Nota&lt;/b&gt;: el cambio del tema de iconos tendrá efecto en el próximo inicio del programa</translation>
    </message>
    <message>
        <source>Character encoding</source>
        <translation>Codificación de caracteres</translation>
    </message>
    <message>
        <source>Length units</source>
        <translation>Longitud de unidades</translation>
    </message>
    <message>
        <source>Page view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will specify which part of editor window will receive keyboard focus when new window is opened</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PageSpace</name>
    <message>
        <source>Save as image ...</source>
        <translation>Guardar como imagen ...</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 de %2</translation>
    </message>
    <message>
        <source>Resizing zone must be positive integer or null !</source>
        <translation type="obsolete">La zona a redimensionar debe ser entero positivo o nulo !</translation>
    </message>
</context>
<context>
    <name>gui::PdfEditWindow</name>
    <message>
        <source>Loaded file</source>
        <translation>Archivo cargado</translation>
    </message>
    <message>
        <source>Current file is not saved. Do you want to save it?</source>
        <translation>El archivo actual no está guardado. ¿Quiéres guardarlo?</translation>
    </message>
    <message>
        <source>Error while loading document </source>
        <translation>Error cargando el documento </translation>
    </message>
    <message>
        <source>Unknown error while loading document </source>
        <translation>Error desconocido cargando el documento </translation>
    </message>
    <message>
        <source>No document to save</source>
        <translation>Ningún documento para guardar</translation>
    </message>
    <message>
        <source>viewing revision</source>
        <translation>viewing revision</translation>
    </message>
    <message>
        <source>Name is empty</source>
        <translation>El nombre está vacío</translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation>El documento está en modo sólo-lectura</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>Error desconocido ocurrido mientras se guardaba el documento</translation>
    </message>
    <message>
        <source>Error occured while saving copy</source>
        <translation type="obsolete">Error ocurrido mientras se guardaba una copia</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>PDF linearizado</translation>
    </message>
    <message>
        <source>Encrypted</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation>Selección</translation>
    </message>
    <message>
        <source>Selected operators</source>
        <translation>Operadores seleccionados</translation>
    </message>
    <message>
        <source>Selected annotations</source>
        <translation>Anotaciones seleccionadas</translation>
    </message>
    <message>
        <source>Saving not implemented:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured while saving copy:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Property</name>
    <message>
        <source>Read only</source>
        <translation>Leer sólo</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Oculto</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
</context>
<context>
    <name>gui::PropertyEditor</name>
    <message>
        <source>No object selected</source>
        <translation>Ningún objeto seleccionado</translation>
    </message>
    <message>
        <source>This type of object does not have any properties</source>
        <translation>Este tipo de objetos no tienen ninguna propiedad</translation>
    </message>
    <message>
        <source>This operator does not have any directly editable parameters</source>
        <translation>Este operador no tiene parámetros directamente editables</translation>
    </message>
    <message>
        <source>This %1 is empty</source>
        <translation>Este %1 está vacio</translation>
    </message>
    <message>
        <source>dictionary</source>
        <comment>property type</comment>
        <translation>diccionario</translation>
    </message>
    <message>
        <source>This %1 does not have any directly editable properties</source>
        <translation>Este %1 no tiene propiedades directamente editables</translation>
    </message>
    <message>
        <source>stream</source>
        <comment>property type</comment>
        <translation>flujo</translation>
    </message>
    <message>
        <source>This array is empty</source>
        <translation>Este array está vacío</translation>
    </message>
    <message>
        <source>This array does not have any directly editable elements</source>
        <translation>Este array no tiene elementos directamente editables</translation>
    </message>
    <message>
        <source>This operator does not have any parameters</source>
        <translation>Este operador no tiene parámetros</translation>
    </message>
</context>
<context>
    <name>gui::QSPage</name>
    <message>
        <source>Invalid operation</source>
        <translation>Operación inválida</translation>
    </message>
    <message>
        <source>Out of range</source>
        <translation>Fuera de rango</translation>
    </message>
    <message>
        <source>Unknown exception</source>
        <translation>Excepción desconocida</translation>
    </message>
</context>
<context>
    <name>gui::QSPdf</name>
    <message>
        <source>Page not found</source>
        <translation>Página no encontrada</translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation>El documento está en modo sólo-lectura</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>Error desconocido ocurrido mientras se guardaba el documento</translation>
    </message>
    <message>
        <source>Unable to save:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::RefPropertyDialog</name>
    <message>
        <source>Reference target</source>
        <translation>Destino de referencia</translation>
    </message>
    <message>
        <source>Choose target for indirect reference</source>
        <translation>Elegir destino para referencia indirecta</translation>
    </message>
    <message>
        <source>Object number</source>
        <translation>Número objeto</translation>
    </message>
    <message>
        <source>Generation number</source>
        <translation>Número generación</translation>
    </message>
    <message>
        <source>Reference target is not valid</source>
        <translation>Destino de referencia no válido</translation>
    </message>
</context>
<context>
    <name>gui::RevisionTool</name>
    <message>
        <source>No revisions</source>
        <translation>Ninguna revisión</translation>
    </message>
    <message>
        <source>Revision: </source>
        <translation>Revisión: </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>PDF linearizado</translation>
    </message>
</context>
<context>
    <name>gui::SelectPagesDialog</name>
    <message>
        <source>Convert pdf to xml</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Settings</name>
    <message>
        <source>Main Toolbar</source>
        <comment>MainToolbar</comment>
        <translation>Barra de Herramientas Principal</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <comment>opts</comment>
        <translation>&amp;Opciones</translation>
    </message>
    <message>
        <source>Main menu</source>
        <comment>MainMenu</comment>
        <translation>Menú principal</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <comment>quit</comment>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <comment>fload</comment>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <comment>fsave</comment>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>New &amp;Window</source>
        <comment>neww</comment>
        <translation>Nueva &amp;Ventana</translation>
    </message>
    <message>
        <source>Page Toolbar</source>
        <comment>PageToolbar</comment>
        <translation>Barra de Herramientas de Página</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <comment>reloadpage</comment>
        <translation type="obsolete">&amp;Recargar página</translation>
    </message>
    <message>
        <source>Add object</source>
        <comment>treeAdditem</comment>
        <translation>Añadir objeto</translation>
    </message>
    <message>
        <source>Delete object</source>
        <comment>treeDelitem</comment>
        <translation>Borrar objeto</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>help_index</comment>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <comment>help_about</comment>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>First Page</source>
        <comment>firstpage</comment>
        <translation>&amp;Primera página</translation>
    </message>
    <message>
        <source>Prev Page</source>
        <comment>prevpage</comment>
        <translation>Pá&amp;gina anterior</translation>
    </message>
    <message>
        <source>Next Page</source>
        <comment>nextpage</comment>
        <translation>Página &amp;siguiente</translation>
    </message>
    <message>
        <source>Last Page</source>
        <comment>lastpage</comment>
        <translation>&amp;Ultima página</translation>
    </message>
    <message>
        <source>Revision Toolbar</source>
        <comment>RevisionToolbar</comment>
        <translation>Barra de Herramientas de Revisión</translation>
    </message>
    <message>
        <source>Revisions</source>
        <comment>revlabel</comment>
        <translation>Revisiones</translation>
    </message>
    <message>
        <source>Rotate page 270 degrees</source>
        <comment>rot-90</comment>
        <translation>R&amp;otar página 270 grados</translation>
    </message>
    <message>
        <source>Rotate page 90 degrees</source>
        <comment>rot90</comment>
        <translation>Rotar página 90 &amp;grados</translation>
    </message>
    <message>
        <source>Save &amp;copy...</source>
        <comment>fsavecopy</comment>
        <translation>Guardar c&amp;opia...</translation>
    </message>
    <message>
        <source>&amp;Page</source>
        <comment>pagemenu</comment>
        <translation>&amp;Página</translation>
    </message>
    <message>
        <source>Save page as image...</source>
        <comment>savepage</comment>
        <translation>&amp;Guardar página como imagen...</translation>
    </message>
    <message>
        <source>Show all operators in stream</source>
        <comment>streamAll</comment>
        <translation>Mostrar todos los operadores en flujo</translation>
    </message>
    <message>
        <source>Show only text operators in stream</source>
        <comment>streamText</comment>
        <translation>Mostrar sólo operadores de texto en flujo</translation>
    </message>
    <message>
        <source>Show only font operators in stream</source>
        <comment>streamFont</comment>
        <translation>Mostrar sólo operadores de fuente en flujo</translation>
    </message>
    <message>
        <source>Operator Toolbar</source>
        <comment>OperatorToolbar</comment>
        <translation>Barra de Herramientas de Operador</translation>
    </message>
    <message>
        <source>Edit page metrics</source>
        <comment>editPageMediaBox</comment>
        <translation>Editar &amp;métrica de página</translation>
    </message>
    <message>
        <source>Close Window</source>
        <comment>closew</comment>
        <translation>&amp;Cerrar Ventana</translation>
    </message>
    <message>
        <source>Show/Hide &amp;commandline</source>
        <comment>hideCmd</comment>
        <translation>Mostrar/Ocultar &amp;línea de comandos</translation>
    </message>
    <message>
        <source>Add system font to page</source>
        <comment>addSystemFont</comment>
        <translation>&amp;Añadir fuente del sistema a página</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <comment>pagetext</comment>
        <translation>&amp;Extraer texto desde página</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <comment>zoom_out</comment>
        <translation>Z&amp;oom out</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <comment>zoom_in</comment>
        <translation>&amp;Zoom in</translation>
    </message>
    <message>
        <source>Show only graphical operators in stream</source>
        <comment>streamGfx</comment>
        <translation>Mostrar sólo operadores gráficos en flujo</translation>
    </message>
    <message>
        <source>Selection mode Toolbar</source>
        <comment>SelectionModeToolbar</comment>
        <translation>Barra de Herramientas en modo de Selección</translation>
    </message>
    <message>
        <source>Select all objects</source>
        <comment>selectAllObjects</comment>
        <translation>Seleccionar todos los objetos</translation>
    </message>
    <message>
        <source>Select text</source>
        <comment>selectText</comment>
        <translation>Seleccionar texto</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <comment>filemenu</comment>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>Save new &amp;revision</source>
        <comment>fsaverev</comment>
        <translation>Guardar nueva &amp;revisión</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <comment>showmenu</comment>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Show/Hide &amp;property editor</source>
        <comment>hideProp</comment>
        <translation>Mostrar/Ocultar &amp;editor de propiedades</translation>
    </message>
    <message>
        <source>Show/Hide object &amp;tree</source>
        <comment>hideTree</comment>
        <translation>Mostrar/Ocultar &amp;arbol de objeto</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <comment>toolsmenu</comment>
        <translation>&amp;Herramientas</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <comment>editopersmenu</comment>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Set color</source>
        <comment>opsetcolor</comment>
        <translation>Establecer color</translation>
    </message>
    <message>
        <source>Set font</source>
        <comment>opsetfont</comment>
        <translation>Establecer fuente</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <comment>opsetdash</comment>
        <translation>Establecer estilo de relleno de línea</translation>
    </message>
    <message>
        <source>Set line width</source>
        <comment>opsetlinewidth</comment>
        <translation>Establecer grosor de línea</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>helpmenu</comment>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>Set page transformation matrix</source>
        <comment>setpagetm</comment>
        <translation>Establecer matriz de &amp;transformación de página</translation>
    </message>
    <message>
        <source>Set relative position of operator</source>
        <comment>opsetposop</comment>
        <translation>Establecer posición relativa de operador</translation>
    </message>
    <message>
        <source>Change relative position</source>
        <comment>opsetpos</comment>
        <translation>Cambiar posición relativa</translation>
    </message>
    <message>
        <source>Show/Hide &amp;status bar</source>
        <comment>hideStatus</comment>
        <translation>Mostrar/Ocultar &amp;barra de estado</translation>
    </message>
    <message>
        <source>Add text</source>
        <comment>addtext</comment>
        <translation>Añadir te&amp;xto</translation>
    </message>
    <message>
        <source>Draw line</source>
        <comment>drawlinee</comment>
        <translation>Dibujar &amp;línea</translation>
    </message>
    <message>
        <source>Draw rectangle</source>
        <comment>drawrecte</comment>
        <translation>Di&amp;bujar rectángulo</translation>
    </message>
    <message>
        <source>Select annotations</source>
        <comment>selectAnnot</comment>
        <translation>Seleccionar anotaciones</translation>
    </message>
    <message>
        <source>Text Toolbar</source>
        <comment>TextToolBar</comment>
        <translation>Barra de Herramientas de Texto</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <comment>searchText</comment>
        <translation>Encontrar &amp;texto</translation>
    </message>
    <message>
        <source>&amp;Insert Pages from other document</source>
        <comment>mergeDoc</comment>
        <translation>&amp;Insertar Páginas desde otro documento</translation>
    </message>
    <message>
        <source>Draw Toolbar</source>
        <comment>DrawToolbar</comment>
        <translation>Dibujar Barra de Herramientas</translation>
    </message>
    <message>
        <source>Move page up</source>
        <comment>pageMoveUp</comment>
        <translation>Mover página hacia arriba</translation>
    </message>
    <message>
        <source>Move page down</source>
        <comment>pageMoveDown</comment>
        <translation>Mover página hacia abajo</translation>
    </message>
    <message>
        <source>Remove page</source>
        <comment>pageRemove</comment>
        <translation>Eliminar página</translation>
    </message>
    <message>
        <source>Highlighting text</source>
        <comment>highlightingtext</comment>
        <translation>Texto re&amp;saltado</translation>
    </message>
    <message>
        <source>Select graphical operators</source>
        <comment>selectGraphical</comment>
        <translation>Seleccionar operadores gráficos</translation>
    </message>
    <message>
        <source>TreeView Toolbar</source>
        <comment>TreeViewToolbar</comment>
        <translation>Barra de Herramientas de Vista de Arbol</translation>
    </message>
    <message>
        <source>Dynamic Toolbar</source>
        <comment>DynamicToolBar</comment>
        <translation>Barra de Herramientas Dinámica</translation>
    </message>
    <message>
        <source>Strike through</source>
        <comment>striketrough</comment>
        <translation>Ta&amp;char</translation>
    </message>
    <message>
        <source>Draw arrow</source>
        <comment>drawarrowe</comment>
        <translation>Dibujar flecha</translation>
    </message>
    <message>
        <source>PageRider Toolbar</source>
        <comment>PageRiderToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as text...</source>
        <comment>fsaveastext</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Page (show changes)</source>
        <comment>reloadpage</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::TreeItemPdf</name>
    <message>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Contornos</translation>
    </message>
</context>
<context>
    <name>gui::TreeWindow</name>
    <message>
        <source>Object</source>
        <translation>Objeto</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Datos</translation>
    </message>
</context>
<context>
    <name>gui::Units</name>
    <message>
        <source>point</source>
        <translation>punto</translation>
    </message>
    <message>
        <source>inch</source>
        <translation>pulgada</translation>
    </message>
    <message>
        <source>inches</source>
        <translation>pulgadas</translation>
    </message>
    <message>
        <source>hands</source>
        <translation>manos</translation>
    </message>
    <message>
        <source>hand</source>
        <translation>mano</translation>
    </message>
    <message>
        <source>foot</source>
        <translation>pie</translation>
    </message>
    <message>
        <source>feet</source>
        <translation>pies</translation>
    </message>
    <message>
        <source>link</source>
        <translation>enlace</translation>
    </message>
    <message>
        <source>links</source>
        <translation>enlaces</translation>
    </message>
    <message>
        <source>yard</source>
        <translation>yarda</translation>
    </message>
    <message>
        <source>yards</source>
        <translation>yardas</translation>
    </message>
    <message>
        <source>rod</source>
        <translation>bara</translation>
    </message>
    <message>
        <source>rods</source>
        <translation>baras</translation>
    </message>
    <message>
        <source>pole</source>
        <translation>pole</translation>
    </message>
    <message>
        <source>poles</source>
        <translation>poles</translation>
    </message>
    <message>
        <source>perch</source>
        <translation>perch</translation>
    </message>
    <message>
        <source>perches</source>
        <translation>perches</translation>
    </message>
    <message>
        <source>fathom</source>
        <translation>braza</translation>
    </message>
    <message>
        <source>fathoms</source>
        <translation>brazas</translation>
    </message>
    <message>
        <source>chain</source>
        <translation>cadena</translation>
    </message>
    <message>
        <source>chains</source>
        <translation>cadenas</translation>
    </message>
    <message>
        <source>furlong</source>
        <translation>furlong</translation>
    </message>
    <message>
        <source>furlongs</source>
        <translation>furlongs</translation>
    </message>
    <message>
        <source>cable</source>
        <translation>cable</translation>
    </message>
    <message>
        <source>mile</source>
        <translation>milla</translation>
    </message>
    <message>
        <source>miles</source>
        <translation>millas</translation>
    </message>
    <message>
        <source>land</source>
        <translation>tierra</translation>
    </message>
    <message>
        <source>lands</source>
        <translation>tierras</translation>
    </message>
    <message>
        <source>league</source>
        <translation>legua</translation>
    </message>
    <message>
        <source>leagues</source>
        <translation>leguas</translation>
    </message>
    <message>
        <source>nautical mile</source>
        <translation>milla náutica</translation>
    </message>
    <message>
        <source>nautical miles</source>
        <translation>millas náuticas</translation>
    </message>
    <message>
        <source>pt : point</source>
        <translation>pt : punto</translation>
    </message>
    <message>
        <source>in : inch</source>
        <translation>in : pulgada</translation>
    </message>
    <message>
        <source>hand : hand</source>
        <translation>hand : mano</translation>
    </message>
    <message>
        <source>ft : foot</source>
        <translation>ft : pie</translation>
    </message>
    <message>
        <source>li : link</source>
        <translation>li : enlace</translation>
    </message>
    <message>
        <source>yd : yard</source>
        <translation>yd : yarda</translation>
    </message>
    <message>
        <source>rd : rod (pole, perch)</source>
        <translation>rd: rod (pole, perch)</translation>
    </message>
    <message>
        <source>ch : chain</source>
        <translation>ch : cadena</translation>
    </message>
    <message>
        <source>mi : mile</source>
        <translation>mi : milla</translation>
    </message>
    <message>
        <source>land : land (league)</source>
        <translation>land : legua</translation>
    </message>
    <message>
        <source>m : meter</source>
        <translation>m : metro</translation>
    </message>
    <message>
        <source>Ym : yottameter</source>
        <translation>Ym : yottameter</translation>
    </message>
    <message>
        <source>Zm : zettameter</source>
        <translation>Zm : zettameter</translation>
    </message>
    <message>
        <source>Em : exameter</source>
        <translation>Em : exameter</translation>
    </message>
    <message>
        <source>Pm : petameter</source>
        <translation>Pm : petameter</translation>
    </message>
    <message>
        <source>Tm : terameter</source>
        <translation>Tm : terameter</translation>
    </message>
    <message>
        <source>Gm : gigameter</source>
        <translation>Gm : gigameter</translation>
    </message>
    <message>
        <source>Mm : megameter</source>
        <translation>Mm : megameter</translation>
    </message>
    <message>
        <source>km : kilometer</source>
        <translation>km : kilometro</translation>
    </message>
    <message>
        <source>hm : hectometer</source>
        <translation>hm : hectómetro</translation>
    </message>
    <message>
        <source>dam : decameter</source>
        <translation>dam : decametro</translation>
    </message>
    <message>
        <source>dm : decimeter</source>
        <translation>dm : decímetro</translation>
    </message>
    <message>
        <source>cm : centimeter</source>
        <translation>cm : centímetro</translation>
    </message>
    <message>
        <source>mm : millimeter</source>
        <translation>mm : milímetro</translation>
    </message>
    <message>
        <source>um : micrometer</source>
        <translation>um : micrómetro</translation>
    </message>
    <message>
        <source>nm : nanometer</source>
        <translation>nm : nanómetro</translation>
    </message>
    <message>
        <source>pm : picometer</source>
        <translation>pm : picómetro</translation>
    </message>
    <message>
        <source>fm : femtometer</source>
        <translation>fm : femtometer</translation>
    </message>
    <message>
        <source>am : attometer</source>
        <translation>am : attometer</translation>
    </message>
    <message>
        <source>zm : zeptometer</source>
        <translation>zm : zeptometer</translation>
    </message>
    <message>
        <source>ym : yoctometer</source>
        <translation>ym : yoctometer</translation>
    </message>
    <message>
        <source>A : angstrom</source>
        <translation>A : angstrom</translation>
    </message>
    <message>
        <source>astronomical unit</source>
        <translation>unidad astronómica</translation>
    </message>
    <message>
        <source>astronomical units</source>
        <translation>unidades astronómicas</translation>
    </message>
    <message>
        <source>AU : astronomical unit</source>
        <translation>AU : unidad astronómica</translation>
    </message>
    <message>
        <source>light year</source>
        <translation>año luz</translation>
    </message>
    <message>
        <source>light years</source>
        <translation>años luz</translation>
    </message>
    <message>
        <source>ly : light year</source>
        <translation>ly : año luz</translation>
    </message>
    <message>
        <source>parsec</source>
        <translation>parsec</translation>
    </message>
    <message>
        <source>pc : parsec</source>
        <translation>pc : parsec</translation>
    </message>
    <message>
        <source>mil : milli-inch</source>
        <translation>mil : mili-pulgada</translation>
    </message>
    <message>
        <source>fm. : fathom</source>
        <translation>fm. : braza</translation>
    </message>
    <message>
        <source>fur. : furlong</source>
        <translation>fur. : brázda</translation>
    </message>
    <message>
        <source>cable : cable</source>
        <translation>cable : kabel</translation>
    </message>
    <message>
        <source>n.m. : nautical mile</source>
        <translation>n.m. : milla náutica</translation>
    </message>
</context>
</TS>
